@@ -8,8 +8,9 @@ FileUtils.rm_rf(testBuildFolder)
 Dir.mkdir testBuildFolder
 
 # Copy the existing dir
-`find . -name '*.go' \
+`find . -name '*.go' -o -name 'go.sum' -o -name 'go.mod' \
         -not -path "./examples/*" \
         -not -path "./testutil/*" \
+        -not -path "./v2/testutil/*" \
         -not -path "./features/*" \
         -not -name '*_test.go' | cpio -pdm #{testBuildFolder}`
